==> com.liferay.layout.content.page.editor.web-2.0.74.jar: META-INF/resources/page_editor/plugins/page-structure/components/item-configuration-panels/EditableLinkPanel.js <==
Liferay.Loader.define("layout-content-page-editor-web@2.0.74/page_editor/plugins/page-structure/components/item-configuration-panels/EditableLinkPanel", ['module', 'exports', 'require', 'frontend-js-react-web$prop-types', 'frontend-js-react-web$react', '../../../../app/components/fragment-configuration-fields/LinkField', '../../../../app/config/constants/editableFragmentEntryProcessor', '../../../../app/config/constants/editableTypes', '../../../../app/selectors/selectEditableValue', '../../../../app/selectors/selectEditableValues', '../../../../app/selectors/selectSegmentsExperienceId', '../../../../app/store/index', '../../../../app/thunks/updateEditableValues', '../../../../app/utils/checkDeepEqual', '../../../../prop-types/index'], function (module, exports, require) {
  var define = undefined;
  var global = window;
  {
    function _typeof(obj) {
      "@babel/helpers - typeof";
      if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") {
        _typeof = function _typeof(obj) {
          return typeof obj;
        };
      } else {
        _typeof = function _typeof(obj) {
          return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj;
        };
      }return _typeof(obj);
    }

    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports["default"] = EditableLinkPanel;

    var _propTypes = _interopRequireDefault(require("frontend-js-react-web$prop-types"));

    var _react = _interopRequireDefault(require("frontend-js-react-web$react"));

    var _LinkField = _interopRequireWildcard(require("../../../../app/components/fragment-configuration-fields/LinkField"));

    var _editableFragmentEntryProcessor = require("../../../../app/config/constants/editableFragmentEntryProcessor");

    var _editableTypes = require("../../../../app/config/constants/editableTypes");

    var _selectEditableValue = _interopRequireDefault(require("../../../../app/selectors/selectEditableValue"));

    var _selectEditableValues = _interopRequireDefault(require("../../../../app/selectors/selectEditableValues"));

    var _selectSegmentsExperienceId = _interopRequireDefault(require("../../../../app/selectors/selectSegmentsExperienceId"));

    var _index = require("../../../../app/store/index");

    var _updateEditableValues = _interopRequireDefault(require("../../../../app/thunks/updateEditableValues"));

    var _checkDeepEqual = require("../../../../app/utils/checkDeepEqual");

    var _index2 = require("../../../../prop-types/index");

    function _getRequireWildcardCache() {
      if (typeof WeakMap !== "function") return null;var cache = new WeakMap();_getRequireWildcardCache = function _getRequireWildcardCache() {
        return cache;
      };return cache;
    }

    function _interopRequireWildcard(obj) {
      if (obj && obj.__esModule) {
        return obj;
      }if (obj === null || _typeof(obj) !== "object" && typeof obj !== "function") {
        return { "default": obj };
      }var cache = _getRequireWildcardCache();if (cache && cache.has(obj)) {
        return cache.get(obj);
      }var newObj = {};var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor;for (var key in obj) {
        if (Object.prototype.hasOwnProperty.call(obj, key)) {
          var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null;if (desc && (desc.get || desc.set)) {
            Object.defineProperty(newObj, key, desc);
          } else {
            newObj[key] = obj[key];
          }
        }
      }newObj["default"] = obj;if (cache) {
        cache.set(obj, newObj);
      }return newObj;
    }

    function _interopRequireDefault(obj) {
      return obj && obj.__esModule ? obj : { "default": obj };
    }

    function ownKeys(object, enumerableOnly) {
      var keys = Object.keys(object);if (Object.getOwnPropertySymbols) {
        var symbols = Object.getOwnPropertySymbols(object);if (enumerableOnly) symbols = symbols.filter(function (sym) {
          return Object.getOwnPropertyDescriptor(object, sym).enumerable;
        });keys.push.apply(keys, symbols);
      }return keys;
    }

    function _objectSpread(target) {
      for (var i = 1; i < arguments.length; i++) {
        var source = arguments[i] != null ? arguments[i] : {};if (i % 2) {
          ownKeys(Object(source), true).forEach(function (key) {
            _defineProperty(target, key, source[key]);
          });
        } else if (Object.getOwnPropertyDescriptors) {
          Object.defineProperties(target, Object.getOwnPropertyDescriptors(source));
        } else {
          ownKeys(Object(source)).forEach(function (key) {
            Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key));
          });
        }
      }return target;
    }

    function _defineProperty(obj, key, value) {
      if (key in obj) {
        Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true });
      } else {
        obj[key] = value;
      }return obj;
    }

    function EditableLinkPanel(_ref) {
      var item = _ref.item;
      var dispatch = (0, _index.useDispatch)();
      var segmentsExperienceId = (0, _index.useSelector)(_selectSegmentsExperienceId["default"]);
      var editableValues = (0, _index.useSelectorCallback)(function (state) {
        return (0, _selectEditableValues["default"])(state, item.fragmentEntryLinkId);
      }, [item.fragmentEntryLinkId]);
      var editableValue = (0, _index.useSelectorCallback)(function (state) {
        var editableValue = (0, _selectEditableValue["default"])(state, item.fragmentEntryLinkId, item.editableId, _editableFragmentEntryProcessor.EDITABLE_FRAGMENT_ENTRY_PROCESSOR) || {};

        if (!editableValue.config) {
          editableValue.config = {};
        }

        return editableValue;
      }, [item.fragmentEntryLinkId, item.editableId], _checkDeepEqual.deepEqual);

      return _react["default"].createElement(_LinkField["default"], {
        field: {
          name: 'link'
        },
        onValueSelect: function handleValueSelect(_, nextConfig) {
          var config = _objectSpread({}, nextConfig);

          if (Object.keys(nextConfig).length > 0 && item.type !== _editableTypes.EDITABLE_TYPES.link) {
            config.mapperType = 'link';
          }

          dispatch((0, _updateEditableValues["default"])({
            editableValues: _objectSpread({}, editableValues, _defineProperty({}, _editableFragmentEntryProcessor.EDITABLE_FRAGMENT_ENTRY_PROCESSOR, _objectSpread({}, editableValues[_editableFragmentEntryProcessor.EDITABLE_FRAGMENT_ENTRY_PROCESSOR], _defineProperty({}, item.editableId, _objectSpread({}, editableValue, {
              config: config
            }))))),
            fragmentEntryLinkId: item.fragmentEntryLinkId,
            segmentsExperienceId: segmentsExperienceId
          }));
        },
        value: editableValue.config
      });
    }
    //# sourceMappingURL=EditableLinkPanel.js.map
  }
});
//# sourceMappingURL=EditableLinkPanel.js.map

==> com.liferay.layout.content.page.editor.web-2.0.122.jar: META-INF/resources/page_editor/plugins/page-structure/components/item-configuration-panels/EditableLinkPanel.js <==
Liferay.Loader.define("layout-content-page-editor-web@2.0.122/page_editor/plugins/page-structure/components/item-configuration-panels/EditableLinkPanel", ['module', 'exports', 'require', 'frontend-js-react-web$prop-types', 'frontend-js-react-web$react', '../../../../app/components/fragment-configuration-fields/LinkField', '../../../../app/config/constants/editableFragmentEntryProcessor', '../../../../app/config/constants/editableTypes', '../../../../app/selectors/selectEditableValue', '../../../../app/selectors/selectEditableValues', '../../../../app/selectors/selectSegmentsExperienceId', '../../../../app/store/index', '../../../../app/thunks/updateEditableValues', '../../../../app/utils/checkDeepEqual', '../../../../prop-types/index'], function (module, exports, require) {
  var define = undefined;
  var global = window;
  {
    function _typeof(obj) {
      "@babel/helpers - typeof";
      if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") {
        _typeof = function _typeof(obj) {
          return typeof obj;
        };
      } else {
        _typeof = function _typeof(obj) {
          return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj;
        };
      }return _typeof(obj);
    }

    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.default = EditableLinkPanel;

    var _propTypes = _interopRequireDefault(require("frontend-js-react-web$prop-types"));

    var _react = _interopRequireDefault(require("frontend-js-react-web$react"));

    var _LinkField = _interopRequireWildcard(require("../../../../app/components/fragment-configuration-fields/LinkField"));

    var _editableFragmentEntryProcessor = require("../../../../app/config/constants/editableFragmentEntryProcessor");

    var _editableTypes = require("../../../../app/config/constants/editableTypes");

    var _selectEditableValue = _interopRequireDefault(require("../../../../app/selectors/selectEditableValue"));

    var _selectEditableValues = _interopRequireDefault(require("../../../../app/selectors/selectEditableValues"));

    var _selectSegmentsExperienceId = _interopRequireDefault(require("../../../../app/selectors/selectSegmentsExperienceId"));

    var _index = require("../../../../app/store/index");

    var _updateEditableValues = _interopRequireDefault(require("../../../../app/thunks/updateEditableValues"));

    var _checkDeepEqual = require("../../../../app/utils/checkDeepEqual");

    var _index2 = require("../../../../prop-types/index");

    function _getRequireWildcardCache() {
      if (typeof WeakMap !== "function") return null;var cache = new WeakMap();_getRequireWildcardCache = function _getRequireWildcardCache() {
        return cache;
      };return cache;
    }

    function _interopRequireWildcard(obj) {
      if (obj && obj.__esModule) {
        return obj;
      }if (obj === null || _typeof(obj) !== "object" && typeof obj !== "function") {
        return { default: obj };
      }var cache = _getRequireWildcardCache();if (cache && cache.has(obj)) {
        return cache.get(obj);
      }var newObj = {};var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor;for (var key in obj) {
        if (Object.prototype.hasOwnProperty.call(obj, key)) {
          var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null;if (desc && (desc.get || desc.set)) {
            Object.defineProperty(newObj, key, desc);
          } else {
            newObj[key] = obj[key];
          }
        }
      }newObj.default = obj;if (cache) {
        cache.set(obj, newObj);
      }return newObj;
    }

    function _interopRequireDefault(obj) {
      return obj && obj.__esModule ? obj : { default: obj };
    }

    function ownKeys(object, enumerableOnly) {
      var keys = Object.keys(object);if (Object.getOwnPropertySymbols) {
        var symbols = Object.getOwnPropertySymbols(object);if (enumerableOnly) symbols = symbols.filter(function (sym) {
          return Object.getOwnPropertyDescriptor(object, sym).enumerable;
        });keys.push.apply(keys, symbols);
      }return keys;
    }

    function _objectSpread(target) {
      for (var i = 1; i < arguments.length; i++) {
        var source = arguments[i] != null ? arguments[i] : {};if (i % 2) {
          ownKeys(Object(source), true).forEach(function (key) {
            _defineProperty(target, key, source[key]);
          });
        } else if (Object.getOwnPropertyDescriptors) {
          Object.defineProperties(target, Object.getOwnPropertyDescriptors(source));
        } else {
          ownKeys(Object(source)).forEach(function (key) {
            Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key));
          });
        }
      }return target;
    }

    function _defineProperty(obj, key, value) {
      if (key in obj) {
        Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true });
      } else {
        obj[key] = value;
      }return obj;
    }

    function EditableLinkPanel(_ref) {
      var item = _ref.item;
      var dispatch = (0, _index.useDispatch)();
      var segmentsExperienceId = (0, _index.useSelector)(_selectSegmentsExperienceId.default);
      var editableValues = (0, _index.useSelectorCallback)(function (state) {
        return (0, _selectEditableValues.default)(state, item.fragmentEntryLinkId);
      }, [item.fragmentEntryLinkId]);
      var editableValue = (0, _index.useSelectorCallback)(function (state) {
        var editableValue = (0, _selectEditableValue.default)(state, item.fragmentEntryLinkId, item.editableId, _editableFragmentEntryProcessor.EDITABLE_FRAGMENT_ENTRY_PROCESSOR) || {};

        if (!editableValue.config) {
          editableValue.config = {};
        }

        return editableValue;
      }, [item.fragmentEntryLinkId, item.editableId], _checkDeepEqual.deepEqual);

      return (/*#__PURE__*/_react.default.createElement(_LinkField.default, {
          field: {
            name: 'link'
          },
          onValueSelect: function handleValueSelect(_, nextConfig) {
            var config = _objectSpread({}, nextConfig);

            if (Object.keys(nextConfig).length > 0 && item.type !== _editableTypes.EDITABLE_TYPES.link) {
              config.mapperType = 'link';
            }

            dispatch((0, _updateEditableValues.default)({
              editableValues: _objectSpread(_objectSpread({}, editableValues), {}, _defineProperty({}, _editableFragmentEntryProcessor.EDITABLE_FRAGMENT_ENTRY_PROCESSOR, _objectSpread(_objectSpread({}, editableValues[_editableFragmentEntryProcessor.EDITABLE_FRAGMENT_ENTRY_PROCESSOR]), {}, _defineProperty({}, item.editableId, _objectSpread(_objectSpread({}, editableValue), {}, {
                config: config
              }))))),
              fragmentEntryLinkId: item.fragmentEntryLinkId,
              segmentsExperienceId: segmentsExperienceId
            }));
          },
          value: editableValue.config
        })
      );
    }
    //# sourceMappingURL=EditableLinkPanel.js.map
  }
});
//# sourceMappingURL=EditableLinkPanel.js.map
